{ config, pkgs, lib, inputs, ... }:
let
  # Firefox Profile Setting States
  lock-false = {
    Value = false;
    Status = "locked";
  };
  lock-true = {
    Value = true;
    Status = "locked";
  };
  lock-empty-string = {
    Value = "";
    Status = "locked";
  };
in {
  programs.firefox = {
    enable = true;
    nativeMessagingHosts = [ pkgs.firefoxpwa ];
    policies = {
      # --------- Privacy ---------
      DisableTelemetry = true;
      DisableFirefoxStudies = true;
      DisablePocket = true;
      DisableFirefoxAccounts = true;
      AutofillAddressEnabled = false;
      AutofillCreditCardEnabled = false;
      OfferToSaveLogins = false;
      FirefoxHome.TopSites = false;
      FirefoxHome.SponsoredTopSites = false;
      Preferences = {
        "browser.newtabpage.pinned" = lock-empty-string;
        "browser.topsites.contile.enabled" = lock-false;
      };
      # -------- Opiniated --------
      DontCheckDefaultBrowser = true;
      DisableProfileImport = true;
      SearchBar = "unified";
      SearchEngines.Add = [ # Only Available in ESR Releases https://mozilla.github.io/policy-templates/#searchengines--add
        {
          Name = "Brave";
          URLTemplate = "https://search.brave.com/search?q={SearchTerms}";
          Alias = "br";
        }
      ];
      # Extensions https://mozilla.github.io/policy-templates#extensionsettings
      ExtensionSettings = {
        "uBlock0@raymondhill.net" = { # uBlock Origin: https://addons.mozilla.org/en-US/firefox/addon/ublock-origin
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4458450/ublock_origin-1.63.2.xpi";
          installation_mode = "normal_installed";
          private_browsing = true;
        };
        "idcac-pub@guus.ninja" = { # I still don't care about cookies: https://addons.mozilla.org/en-US/firefox/addon/istilldontcareaboutcookies/
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4216095/istilldontcareaboutcookies-1.1.4.xpi";
          installation_mode = "normal_installed";
          private_browsing = true;
        };
        "keepassxc-browser@keepassxc.org" = { # KeePassXC-Browser: https://addons.mozilla.org/en-US/firefox/addon/keepassxc-browser
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4441759/keepassxc_browser-1.9.7.xpi";
          installation_mode = "normal_installed";
        };
        "offline-qr-code@rugk.github.io" = { # Offline QR Code Generator: https://addons.mozilla.org/en-US/firefox/addon/offline-qr-code-generator/
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4349427/offline_qr_code_generator-1.9.xpi";
          installation_mode = "normal_installed";
        };
        "addon@darkreader.org" = { # Dark Reader: https://addons.mozilla.org/en-US/firefox/addon/darkreader/
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4439735/darkreader-4.9.103.xpi";
          installation_mode = "normal_installed";
        };
        "languagetool-webextension@languagetool.org" = { # LanguageTool: https://addons.mozilla.org/en-US/firefox/addon/languagetool
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4470413/languagetool-8.19.4.xpi";
          installation_mode = "normal_installed";
        };
      };
      Bookmarks = [
        {
          Title = "Syncthing";
          URL = "localhost:8384";
          Placement = "toolbar";
        }
        {
          Title = "BayZeit";
          URL = "https://bayzeit-web.ur.de/";
          Placement = "toolbar";
          Folder = "OHM";
        }
        {
          Title = "Zimbra";
          URL = "https://my.ohmportal.de/zimbra/#1";
          Placement = "toolbar";
          Folder = "OHM";
        }
        {
          Title = "Moodle";
          URL = "https://elearning.ohmportal.de/my/courses.php";
          Placement = "toolbar";
          Folder = "OHM";
        }
        {
          Title = "Ohmportal";
          URL = "https://my.ohmportal.de/";
          Placement = "toolbar";
          Folder = "OHM";
        }
        {
          Title = "Intranet";
          URL = "https://intern.ohmportal.de/seitenbaum/home/page.html";
          Placement = "toolbar";
          Folder = "OHM";
        }
        {
          Title = "Kantine Hohfederstraße";
          URL = "https://www.werkswelt.de/?id=hohf";
          Placement = "toolbar";
          Folder = "OHM";
        }
        {
          Title = "Kantine Keßlerplatz";
          URL = "https://www.werkswelt.de/index.php?id=mohm";
          Placement = "toolbar";
          Folder = "OHM";
        }
        {
          Title = "NixOS Search - Packages";
          URL = "https://search.nixos.org/packages?channel=unstable";
          Placement = "toolbar";
          Folder = "NixOS";
        }
        {
          Title = "NixOS Search - Options";
          URL = "https://search.nixos.org/options?channel=unstable";
          Placement = "toolbar";
          Folder = "NixOS";
        }
        {
          Title = "Home Manager Search - Options";
          URL = "https://home-manager-options.extranix.com/?release=master";
          Placement = "toolbar";
          Folder = "NixOS";
        }
        {
          Title = "Lix";
          URL = "https://lix.systems/";
          Placement = "toolbar";
          Folder = "NixOS";
        }
        {
          Title = "AUX - Homepage";
          URL = "https://auxolotl.org/en/";
          Placement = "toolbar";
          Folder = "NixOS";
        }
        {
          Title = "AUX - Forum";
          URL = "https://forum.aux.computer/";
          Placement = "toolbar";
          Folder = "NixOS";
        }
        {
          Title = "NixOS & Flakes Book";
          URL = "https://nixos-and-flakes.thiscute.world/introduction/";
          Placement = "toolbar";
          Folder = "NixOS";
        }
        {
          Title = "Nix Pills";
          URL = "https://nixos.org/guides/nix-pills/";
          Placement = "toolbar";
          Folder = "NixOS";
        }
      ];
    };
  };

}

