{ config, pkgs, lib, inputs, ... }:
{
  programs.chromium = {
    enable = true;
    package = pkgs.ungoogled-chromium;
    commandLineArgs = [
      "--extension-mime-request-handling=always-prompt-for-install" # Enable Extension-Install Dialogue
      "--enable-features=ClearDataOnExit,NoReferrers,SpoofWebGLInfo" # Feature Flags
      "--no-default-browser-check"
    ];
    extensions = let
      createChromiumExtensionFor = browserVersion: { id, sha256, version }: {
        inherit id;
        crxPath = builtins.fetchurl {
          url = "https://clients2.google.com/service/update2/crx?response=redirect&acceptformat=crx2,crx3&prodversion=${browserVersion}&x=id%3D${id}%26installsource%3Dondemand%26uc";
          name = "${id}.crx";
          inherit sha256;
        };
        inherit version;
      };
      createChromiumExtension = createChromiumExtensionFor (lib.versions.major pkgs.ungoogled-chromium.version);
    in [
      { # Chromium Web Store
        id = "ocaahdebbfolfmndjeplogmgcagdmblk";
        crxPath = builtins.fetchurl {
          url = "https://github.com/NeverDecaf/chromium-web-store/releases/download/v1.5.4.3/Chromium.Web.Store.crx";
          name = "ocaahdebbfolfmndjeplogmgcagdmblk.crx";
          sha256 = "sha256:0ck5k4gs5cbwq1wd5i1aka5hwzlnyc4c513sv13vk9s0dlhbz4z5";
        };
        version = "1.5.4.3";
      }
      (createChromiumExtension { # uBlock Origin
        id = "cjpalhdlnbpafiamejdnhcphjbkeiagm";
        sha256 = "sha256:0pdh1v0vx1d5vnl1zh7nbk6j1fh4k4hhwp1ljs203icn306lahsn";
        version = "1.64.0";
      })
      (createChromiumExtension { # I still don't care about cookies
        id = "edibdbjcniadpccecjdfdjjppcpchdlm";
        sha256 = "sha256:11k7cxcjafs8ziaxl4bilbfwbgl2yf1p6v1bvwszadcr14xyvgsj";
        version = "1.1.4";
      })
      (createChromiumExtension { # KeePassXC-Browser
        id = "oboonakemofpalcgghocfoadofidjkkk";
        sha256 = "sha256:0zlmwiyzn4cznzrvavp2nsj07v4lrdyi7nw5aarqnj7nj12gixh7";
        version = "1.9.8";
      })
      (createChromiumExtension { # LanguageTool
        id = "oldceeleldhonbafppcapldpdifcinji";
        sha256 = "sha256:184iavn085z11c0zh7f5m4yzw35kc2w3qx634ffnlqixgsnqmdc2";
        version = "8.20.0";
      })
      (createChromiumExtension { # dark reader
        id = "eimadpbcbfnmbkopoojfekhnkhdbieeh";
        sha256 = "sha256:1lc5ny57rdpqzx07gwj44pl3m9mg9nq6p5kjchrmjjh4hkk5wsny";
        version = "4.9.106";
      })
    ];
  };
}
