{ config, lib, pkgs, modulesPath, inputs, ... }: let
  inherit (inputs) nixos-hardware;
in {
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
    nixos-hardware.nixosModules.apple-t2
  ];

  # Nix Config
  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";

  # Kernel
  boot.initrd.availableKernelModules = [ "xhci_pci" "nvme" "usbhid" "usb_storage" "sd_mod" "cryptd" ];
  boot.initrd.kernelModules = [ ];
  boot.kernelModules = [ "kvm-intel" ];
  boot.extraModulePackages = [ ];
  boot.supportedFilesystems = [ "zfs" ];
  boot.zfs.forceImportRoot = false;
  networking.hostId = "60dbcc20";

  # Boot Process
  boot.loader.systemd-boot.enable = true;
  boot.initrd.systemd.enable = true;
  boot.plymouth.enable = true;
  boot.plymouth.logo = pkgs.fetchurl {
    url = "https://forum.auxolotl.org/uploads/default/original/1X/be37690f0748737fc813dd3592848f5323a7f277.png";
    hash = "sha256-+E7mAoEMnHsavKzEdTosli08Oohq+yt3WB4Uhwpi0Vg=";
  };
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.efi.efiSysMountPoint = "/boot";

  # File Systems
  fileSystems."/" = { 
    device = "/dev/disk/by-uuid/e36a3f85-020f-4d6c-844f-b81131ce7e63";
    fsType = "ext4";
  };
  boot.initrd.luks.devices."luks-a226aaf4-1250-447b-a5fc-fa37758d332a".device = "/dev/disk/by-uuid/a226aaf4-1250-447b-a5fc-fa37758d332a";
  boot.initrd.luks.devices."luks-a226aaf4-1250-447b-a5fc-fa37758d332a".crypttabExtraOpts = ["fido2-device=auto"];
  fileSystems."/boot" = { 
    device = "/dev/disk/by-uuid/5F66-17ED";
    fsType = "vfat";
    options = [ "fmask=0022" "dmask=0022" ];
  };
  swapDevices = [ { device = "/swapfile"; size = 8 * 1024; } ];

  # Misc
  networking.useDHCP = lib.mkDefault true;

  # Firmware
  hardware.apple-t2.firmware.enable = true;
  hardware.cpu.intel.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
